@@ -15,11 +15,9 @@
 ;;   "vlp" references would be gone.
 
 (define-module binary.pack
-  (use srfi-1)
   (use srfi-11)   ;; let-values
   (use srfi-13)   ;; string library
   (use srfi-14)   ;; char-set library
-  (use util.list) ;; list library (srfi-1+)
   (use text.parse)
   (use gauche.uvector)
   (use gauche.parameter)
@@ -603,7 +601,7 @@
                   (lambda ()
                     (let* ((actual-count (get-count (count-unpack)))
                            (bstr (read-block actual-count))
-                           (str (or (string-incomplete->complete! bstr) bstr))
+                           (str (or (string-incomplete->complete bstr) bstr))
                            (size (string-size str)))
                       (list
                        (if (< size actual-count)
@@ -612,7 +610,7 @@
                  (else
                   (lambda ()
                     (let* ((bstr (read-block count))
-                           (str (or (string-incomplete->complete! bstr) bstr))
+                           (str (or (string-incomplete->complete bstr) bstr))
                            (size (string-size str)))
                       (list
                        (if (< size count)
@@ -1010,7 +1008,7 @@
 ;; threads with a mutex.
 (define make-packer
   (let ((cache (make-parameter (make-hash-table 'equal?))))
-    (lambda (template cached?)
+    (lambda (template :optional (cached? #t))
       (if cached?
         (let ((res (hash-table-get (cache) template #f)))
           (unless res
